@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import re
 import datetime
-
 import requests
 from bs4 import BeautifulSoup
 
@@ -52,8 +52,24 @@ def scrape_google(cve: str, base_url="https://www.google.com/search?q=", start_p
                             search_result['link'], timeout=5)
                         if page_resp.status_code == 200:
                             page_soup = BeautifulSoup(
-                                page_resp.text, "html.parser")
-                            page_data = page_soup.find('body').text
+                                page_resp.text, "html.parser")                                    
+                            [x.decompose() for x in page_soup.findAll('script')]
+                            [x.decompose() for x in page_soup.findAll('footer')]
+                            [x.decompose() for x in page_soup.findAll('header')]
+                            [x.decompose() for x in page_soup.findAll('option')]
+                            [x.decompose() for x in page_soup.findAll('style')]
+                            [x.decompose() for x in page_soup.findAll('a')]
+                            [x.decompose() for x in page_soup.findAll('iframe')]
+                            [x.decompose() for x in page_soup.findAll('img')]
+                            [x.decompose() for x in page_soup.findAll('input')]
+                            [x.decompose() for x in page_soup.findAll('label')]
+                            [x.decompose() for x in page_soup.findAll('button')]
+                            [x.decompose() for x in page_soup.findAll('form')]
+                            [x.decompose() for x in page_soup.findAll('aside')]
+                            [x.decompose() for x in page_soup.findAll('code')]
+                            [x.decompose() for x in page_soup.findAll('noscript')]
+                            [x.decompose() for x in page_soup.findAll('ins')]                            
+                            page_data = re.sub('\s{2,}|\n',' ',page_soup.find('body').get_text(separator="\n", strip=True))
                         else:
                             page_data = 'Not Avail'
                     except:
@@ -66,10 +82,12 @@ def scrape_google(cve: str, base_url="https://www.google.com/search?q=", start_p
                             date_span_text, "%b %d, %Y").date()
                     except:
                         date_span = None
-                    search_result['short_desc'] = short_desc.replace(
-                        date_span_text + ' - ', '')
                 else:
                     date_span = None
+                if short_desc:
+                    search_result['short_desc'] = short_desc.replace(
+                    date_span_text + ' - ', '')
+                else:
                     search_result['short_desc'] = short_desc
                 search_result['date'] = date_span
                 search_result['page'] = (page_no / 10) + 1
